<?php

namespace App\Http\Controllers\Admin;

use Illuminate\Http\Request;
use App\Http\Controllers\Controller;

use App\Project;
use App\Attachment;
use App\Userdata;
use App\Country;
use App\Team;
use App\Review;
use App\User;

use DB;
use Auth;

class InscriptionController extends Controller
{

    public function __construct()

    {
        // $this->middleware('auth');
    }


    /**
     * Display a listing of the resource.
     * @return Response
     */
    public function index()
    {
        // test categorias de proyecto
        // $a = \App\Project::with('categories')->find(47552);
        // dd($a->categories);

        // FILTROS
        if (isset($_GET['filtroPais'])) {
            $idPais = $_GET['filtroPais'];
        } else {
            $idPais = null;
        }

        if (isset($_GET['filtroTipoInscripcion'])) {
            $idTipoInscripcion = $_GET['filtroTipoInscripcion'];
        } else {
            $idTipoInscripcion = null;
        }

        if (isset($_GET['filtroResenia'])) {
            $idResenia = $_GET['filtroResenia'];
        } else {
            $idResenia = null;
        }

        // buscador detallado
        if (isset($_GET['q']) && !empty($_GET['q'])) {
            $textoDetalleProyecto = $_GET['q'];
        } else {
            $textoDetalleProyecto = null;
        }

        if (isset($_GET['filtroCategoria'])) {
            $idCategoria = $_GET['filtroCategoria'];
        } else {
            $idCategoria = null;
        }

        if (isset($_GET['filtroRating'])) {
            $idRating = $_GET['filtroRating'];
        } else {
            $idRating = null;
        }


        // usuario logueado
        $user = Auth::user();

        // Id de la etapa activa
        $stage = DB::table('stages')
            ->where('active', '=', 1)
            ->get();
        $etapa_activa = $stage->pluck('id')->first();

        $searchValues = preg_split('/\s+/', $textoDetalleProyecto, -1, PREG_SPLIT_NO_EMPTY);


        //Lista de proyectos
        if ($user->hasRole('superadmin') || $user->hasRole('administrador')) {
            $projects = Project::where('projects.title', '!=', 'null')
                ->where('projects.active', '=', 1)
                
                // filtro por tipo de proyecto
                ->when(!is_null($idTipoInscripcion), function ($projects) use ($idTipoInscripcion) {

                    $projects->join('inscriptions', 'inscriptions.project_id', 'projects.id')
                        ->join('types', 'types.id', '=', 'inscriptions.type_id')
                        ->where('types.id', '=', $idTipoInscripcion);
                })
                // filtro por reseñado
                ->when(!is_null($idResenia), function ($projects) use ($idResenia) {
                    $proyectosFiltrados = $this->filtroResenia($idResenia);

                    // 1 => Evaluado, 2 = > En Proceso, 3 = > NO Evaluado, 4 = > En Reevaluacion
                    if ($idResenia == 1) {
                        $projects->whereIn('projects.id', $proyectosFiltrados);
                    } elseif ($idResenia == 2) {
                        $projects->whereIn('projects.id', $proyectosFiltrados);
                    } elseif ($idResenia == 3) {
                        $projects->whereNotIn('projects.id', $proyectosFiltrados);
                    } elseif ($idResenia == 4) {
                        $projects->whereIn('projects.id', $proyectosFiltrados);
                    }
                })
                // filtro por categoria de proyecto
                ->when(!is_null($idCategoria), function ($projects) use ($idCategoria) {

                    $projects->join('taggable_taggables', 'taggable_taggables.taggable_id', '=', 'projects.id')
                        ->join('taggable_tags', 'taggable_tags.tag_id', '=', 'taggable_taggables.tag_id')
                        ->where('taggable_taggables.tag_id', '=', $idCategoria);
                })
                // filtro por rating
                ->when(!is_null($idRating), function ($projects) use ($idRating) {

                    $projects->join('reviews', 'reviews.project_id', 'projects.id')
                        ->where('reviews.type', '=', 'review')
                        ->where('reviews.rating', '=', $idRating);
                })

                // Buscador de detalles del proyecto
                ->when(!is_null($textoDetalleProyecto), function ($projects) use ($textoDetalleProyecto, $idPais, $searchValues) {
                    // package de busqueda
                    $projects->search($textoDetalleProyecto, 1, true)
                                ->orderBy('relevance', 'desc');
                    // dd($projects);
                })
                
                // si NO USA el buscador, ordena los proyectos por Origin_id
                ->when(is_null($textoDetalleProyecto), function ($projects) {
                    $projects->orderBy('origin_id', 'asc');
                })

                // filtro por pais
                ->when(!is_null($idPais), function ($projects) use ($idPais) {
                    $projects->join('users', 'users.id', '=', 'projects.user_id')
                                ->join('userdata', 'userdata.user_id', '=', 'users.id')
                                ->join('countries', 'countries.id', '=', 'userdata.country_id')
                                ->where('countries.id', '=', $idPais);
                })

                // mandar datos
                ->when(!is_null($idTipoInscripcion) || !is_null($idPais) || !is_null($idResenia) || !is_null($textoDetalleProyecto), function ($projects) use ($idTipoInscripcion) {
                    return $projects;
                })

                ->select('projects.origin_id', 'projects.title', 'projects.id', 'projects.user_id', 'projects.preselected')
                
                ->get()->unique();
            // dd($collectionFiltrado);
            // ->get();
            // dd($projects->first());

            // agregar si reseño o no
            $evaluados = $this->filtroResenia(1);
            $enProceso = $this->filtroResenia(2);
            $noEvaluadosQuitar = $this->filtroResenia(3);
            $enReevaluacion = $this->filtroResenia(4);

            // dd($enReevaluacion);
            
            foreach ($projects as $key => $value) {
                if (in_array($value->id, $evaluados)) {
                    $value->reseniado = 'EVALUADO';
                } elseif (in_array($value->id, $enProceso)) {
                    $value->reseniado = 'EN PROCESO';
                } elseif (in_array($value->id, $enReevaluacion)) {
                    $value->reseniado = 'EN REEVALUACION';
                } else {
                    $value->reseniado = 'NO EVALUADO';
                }

                // if (in_array($value->id, $noEvaluadosQuitar)) {
                //     $value->reseniado = 'NO EVALUADO';
                // }
            }

        } elseif ($user->hasRole('revisor')) {
            $projects = Project::join('project_revisor', 'project_revisor.project_id', '=', 'projects.id')
                ->join('stages', 'project_revisor.stage_id', '=', 'stages.id')
                ->where('projects.title', '!=', 'null')
                ->where('project_revisor.stage_id', '=', $etapa_activa)
                ->where('project_revisor.revisor_id', '=', $user->id)
                ->where('projects.active', '=', 1)
                // ->groupBy('projects.id')

                // Buscador de detalles del proyecto
                ->when(!is_null($textoDetalleProyecto), function ($projects) use ($textoDetalleProyecto, $idPais) {
                    // package de busqueda
                    $projects->search($textoDetalleProyecto, 1, true)
                                ->orderBy('relevance', 'desc');
                })

                // Si no usa el buscador, ordena los proyectos por Origin_id
                ->when(is_null($textoDetalleProyecto), function ($projects) {
                    $projects->orderBy('origin_id', 'asc');
                })

                ->select('projects.origin_id', 'projects.title', 'projects.id', 'projects.user_id', 'project_revisor.group_id')
                ->get();

            // agregar si reseño o no
            $evaluados = $this->filtroResenia(1);
            $enProceso = $this->filtroResenia(2);
            $noEvaluadosQuitar = $this->filtroResenia(3);

            // dd($noEvaluadosQuitar);
            foreach ($projects as $key => $value) {
                $rev = DB::table('reviews')
                    ->join('project_revisor', 'reviews.revisor_id', '=', 'project_revisor.revisor_id')
                    ->join('stages', 'stages.id', '=', 'project_revisor.stage_id')
                    
                    ->where('stages.active', '=', 1)
                    ->where('reviews.project_id', '=', $value->id)
                    // ->where('reviews.revisor_id', '=', \Auth::id())
                    ->where('reviews.type', '=', 'review')

                    ->groupBy('reviews.revisor_id')

                    ->select('reviews.project_id', 'reviews.revisor_id')
                    
                    ->get();

                if ($rev->isNotEmpty()) {
                    // dd($rev);
                    foreach ($rev as $rev_key => $rev_value) {
                        if ($rev_value->revisor_id == \Auth::id()) {
                            $value->reseniado = 'EVALUADO';
                            break;
                        }else{
                        // dd($rev_value);
                            $value->reseniado = 'EN REEVALUACION';
                        }
                    }
                } else {
                    $value->reseniado = 'NO EVALUADO';
                }
            }
       

        }


        //Cantidad de proyectos
        if ($user->hasRole('superadmin') || $user->hasRole('administrador')) {
            $total_proyectos = Project::where('title', '!=', 'null')
                ->where('active', '=', 1)
                ->count();

            $cantidad_proyectos_evaluados = null;

            $cantidad_proyectos_pendientes = null;

        } elseif ($user->hasRole('revisor')) {
            $total_proyectos = Project::join('project_revisor', 'project_revisor.project_id', '=', 'projects.id')
                ->join('stages', 'project_revisor.stage_id', '=', 'stages.id')
                ->where('project_revisor.revisor_id', '=', $user->id)
                ->where('project_revisor.stage_id', '=', $etapa_activa)
                ->where('projects.title', '!=', 'null')
                ->where('projects.active', '=', 1)
                ->count();

            $coleccion_evaluados = $projects->filter(function ($value, $key) {
                return $value->reseniado == "EVALUADO";
            });

            $cantidad_proyectos_evaluados = $coleccion_evaluados->count();

            $coleccion_NO_evaluados = $projects->filter(function ($value, $key) {
                return $value->reseniado == "NO EVALUADO";
            });

            $cantidad_proyectos_pendientes = $coleccion_NO_evaluados->count();
        }

        // Listado de estado de reseña para el select
        if ($user->hasRole('superadmin') || $user->hasRole('administrador')) {
            $estadosEvaluacion = collect();

            // 1 => Evaluado, 2 = > En Proceso, 3 = > NO Evaluado, 4 = > En Reevaluacion
            // EVALUADOS
            $cantidadEvaluados = count($this->filtroResenia(1));
            $evaluados = array();
            $evaluados["titulo"] = "Evaluado";
            $evaluados["id"] = 1;
            $evaluados["cantidad"] = $cantidadEvaluados;

            // EN PROCESO
            $cantidadEnProceso = count($this->filtroResenia(2));
            $enProceso = array();
            $enProceso["titulo"] = "En Proceso";
            $enProceso["id"] = 2;
            $enProceso["cantidad"] = $cantidadEnProceso;

            // EN REEVALUACION
            $cantidadEnReevaluacion = count($this->filtroResenia(4));
            $enReevaluacion = array();
            $enReevaluacion["titulo"] = "En Reevaluacion";
            $enReevaluacion["id"] = 4;
            $enReevaluacion["cantidad"] = $cantidadEnReevaluacion;


            $cantidadTotalProyectos = Project::where('projects.title', '!=', 'null')
                ->where('projects.active', '=', 1)
                ->count();

            $cantidadNoEvaluados = $cantidadTotalProyectos - $cantidadEvaluados - $cantidadEnProceso;
             // - $cantidadEnReevaluacion;
            ($cantidadNoEvaluados < 0) ? $cantidadNoEvaluados = 0 : $cantidadNoEvaluados;
            // dd($cantidadNoEvaluados);
            $noEvaluados = array();
            $noEvaluados["titulo"] = "No Evaluado";
            $noEvaluados["id"] = 3;
            $noEvaluados["cantidad"] = $cantidadNoEvaluados;
            // dd($noEvaluados);

            $estadosEvaluacion->push($evaluados);
            $estadosEvaluacion->push($enProceso);
            $estadosEvaluacion->push($enReevaluacion);
            $estadosEvaluacion->push($noEvaluados);

            $estadosEvaluacion;
        } else {
            $estadosEvaluacion = null;
        }

        //Listado de paises para el select
        if ($user->hasRole('superadmin') || $user->hasRole('administrador')) {
            $paises = DB::table('countries')
                ->join('userdata', 'countries.id', '=', 'userdata.country_id')
                ->join('users', 'users.id', 'userdata.user_id')
                ->join('projects', 'projects.user_id', '=', 'users.id')
                ->where('projects.active', '=', 1)
                ->where('projects.title', '!=', 'null')
                ->select('countries.es as pais', 'countries.id', DB::raw('count(*) as cantidadPorPais'))
                ->groupBy('countries.es')
                ->get();
        } else {
            $paises = null;
        }

        //Listado de tipo de proyectos para el select
        if ($user->hasRole('superadmin') || $user->hasRole('administrador')) {
            $array_tipo_proyecto = DB::table('types')
                // ->join('inscriptions', 'inscriptions.type_id', 'types.id')
                // ->join('projects', 'projects.id', '=', 'inscriptions.project_id')
                ->join('projects', 'projects.type', '=', 'types.slug')
                ->where('projects.active', '=', 1)
                ->where('projects.title', '!=', 'null')
                ->select('types.name', 'types.id', DB::raw('count(*) as cantidadPorTipo'))
                ->groupBy('types.name')
                ->get();
            // dd($array_tipo_proyecto);

        } else {
            $array_tipo_proyecto = null;
        }


        //Listado de revisores
        if ($user->hasRole('superadmin') || $user->hasRole('administrador')) {
            $listaRevisores = User::join('userdata', 'userdata.user_id', '=', 'users.id')
                ->select('users.id', 'userdata.name', 'userdata.surname')
                ->role('revisor')->get();
            // dd($listaRevisores);
        } else {
            $listaRevisores = null;
        }

        //Listado de tipo de categoria de proyectos
        if ($user->hasRole('superadmin') || $user->hasRole('administrador')) {
            $listaCategorias = DB::table('taggable_tags')
                ->join('taggable_taggables', 'taggable_taggables.tag_id', '=', 'taggable_tags.tag_id')
                ->join('projects', 'projects.id', '=', 'taggable_taggables.taggable_id')
                ->where('projects.active', '=', 1)
                ->where('projects.title', '!=', 'null')
                ->select('taggable_tags.tag_id as id', 'taggable_tags.es as name', DB::raw('count(projects.id) as cantidadPorCategoria'))
                ->groupBy('name')
                ->get();
            // dd($listaCategorias);
        } else {
            $listaCategorias = null;
        }

        // Listado de rating para el select
        if ($user->hasRole('superadmin') || $user->hasRole('administrador')) {
            $listaRating = collect();

            $rating = array();

            for ($i = 1; $i <= 10; $i++) {
                $cantidadRating = Review::where('type', '=', 'review')
                    ->where('rating', '=', $i)
                    ->count();

                $rating["titulo"] = $i;
                $rating["id"] = $i;
                $rating["cantidad"] = $cantidadRating;

                $listaRating->push($rating);
            }

        } else {
            $listaRating = null;
        }


        //$preselected = $this->preselected;

//        foreach($projects as $key => $value) {
//
//                echo$projects[$key];
//
//            };
//        die();

        $args = [

            'projects' => $projects,
            'total_proyectos' => $total_proyectos,
            'cantidad_proyectos_evaluados' => $cantidad_proyectos_evaluados,
            'cantidad_proyectos_pendientes' => $cantidad_proyectos_pendientes,
            'paises' => $paises,
            'array_tipo_proyecto' => $array_tipo_proyecto,
            'listaRevisores' => $listaRevisores,
            'estadosEvaluacion' => $estadosEvaluacion,
            'listaCategorias' => $listaCategorias,
            'listaRating' => $listaRating,

        ];

        if(isset($_GET['group'])){
            return view('admin.models.inscription.collection-group', $args);
        }else{
            return view('admin.models.inscription.collection', $args);
        }

    }


    /**
     * Show the form for creating a new resource.
     *
     * }
     * @return Response
     */

    public function create()

    {


    }


    /**
     * Store a newly created resource in storage.
     *
     * @return Response
     */

    public function store(Request $request)

    {


    }


    /**
     * Display the specified resource.
     *
     * @param  int $id
     * @return Response
     */

    public function show($id)

    {

        $user = Auth::user();
        if ($user->hasRole('revisor')) {
            $estaAsignado = DB::table('project_revisor')
                ->where('project_id', '=', $id)
                ->where('revisor_id', '=', $user->id)
                ->get();
            if ($estaAsignado->isEmpty()) {
                return redirect('admin');
            }
        }


        $proyecto = Project::where('projects.id', $id)->first();

        $tipo_proyecto = Project::where('projects.id', $id)
            ->join('taggable_taggables', 'taggable_taggables.taggable_id', '=', 'projects.id')
            ->join('taggable_tags', 'taggable_tags.tag_id', '=', 'taggable_taggables.tag_id')
            ->select('taggable_tags.es as tipo_proyecto')
            ->first();

        // dd($proyecto);

        $archivosAdjuntos = Attachment::where('hash', $proyecto->hash)
            ->get();

        $adjuntos = $archivosAdjuntos->toArray();

        $usuario = Userdata::join('users', 'userdata.user_id', '=', 'users.id')
            ->join('projects', 'users.id', '=', 'projects.user_id')
            ->join('countries', 'countries.id', '=', 'userdata.country_id')
            ->select('userdata.*', 'users.email', 'countries.es as pais')
            ->where('projects.user_id', '=', $proyecto->user_id)
            ->get()
            ->first();

        //Redirect 404 si no existe el proyecto completo
        if (is_null($usuario)) {
            abort('404');
        }

        $integrantes_grupo = Userdata::join('users', 'users.id', '=', 'userdata.user_id')
            ->join('team_user', 'team_user.user_id', '=', 'users.id')
            ->join('teams', 'team_user.team_id', '=', 'teams.id')
            ->join('projects', 'projects.team_id', '=', 'teams.id')
            ->join('countries', 'countries.id', '=', 'userdata.country_id')
            ->where('projects.team_id', '=', $proyecto->team_id)
            ->select('userdata.*', 'users.email as email', 'countries.es as pais', 'teams.name as nombreGrupo')
            ->get();

        // dd($integrantes_grupo);

        // $resenias = $reseniasDelProyecto = Review::join('users', 'users.id', '=', 'reviews.revisor_id')
        //     ->select('reviews.*', 'users.name as nombreRevisor')
        //     ->where('project_id', '=', $id)
        //     ->where('type', '=', 'review')
        //     ->get();

        // dd($resenias);

        $resenias = $reseniasDelProyecto = Review::join('users', 'users.id', '=', 'reviews.revisor_id')
            ->select('reviews.*', 'users.name as nombreRevisor', DB::raw('COUNT(*) as count'))
            ->where('project_id', '=', $id)
            ->where('type', '=', 'review')
            ->groupBy('revisor_id', 'comment', 'rating')
            // ->having('count', '>', 1)
            ->oldest()
            ->get();

        // dd($resenias);

        $resenias = $reseniasDelProyecto->when($user->hasRole('revisor'), function ($query) use ($user, $proyecto) {
            $revisoresId = \DB::table('project_revisor')
                                ->select('revisor_id')
                                ->where('project_id', '=', $proyecto->id)
                                ->get();
            $revisores_lista = $revisoresId->pluck('revisor_id')->toArray();
            return $query->whereIn('revisor_id', $revisores_lista);
        });
        // dd($resenias);

        $messages = Review::join('users', 'users.id', '=', 'reviews.revisor_id')
            ->where('project_id', '=', $id)
            ->where('type', '=', 'message')
            ->select('reviews.*', 'users.name as nombreAutor')
            // ->latest()
            ->get();

        $arrayRating = array();
        for ($i = 1; $i <= 10; $i++) {
            $arrayRating[$i] = $i;
        }


        $args = [
            'proyecto' => $proyecto,
            'tipo_proyecto' => $tipo_proyecto,
            'adjuntos' => $adjuntos,
            'usuario' => $usuario,
            'grupo' => $integrantes_grupo,
            'arrayRating' => $arrayRating,
            'reseniasDelProyecto' => $resenias,
            'messages' => $messages,
        ];

        return view('admin.models.inscription.detail', $args);

    }


    /**
     * Show the form for editing the specified resource.
     *
     * @param  int $id
     * @return Response
     */

    public function edit($id)

    {


    }


    /**
     * Update the specified resource in storage.
     *
     * @param  int $id
     * @return Response
     */

    public function update(Request $request)

    {


    }


    /**
     * Remove the specified resource from storage.
     *
     * @param  int $id
     * @return Response
     */

    public function destroy($id)

    {


    }


    public function slugify($text)

    {

    }

    public function preselectProject($idProject)
    {
        $project = Project::where('id', '=', $idProject)->first();
        ($project->preselected == 1)? $project->preselected=0 : $project->preselected=1;
        $project->save();
        return back();
    }

    public function archiveProject($idProject)
    {
        $project = Project::where('id', '=', $idProject)
            ->first();

        $project->active = 0;

        $project->save();

        return back();
    }


    // Funcion de filtros en listado de proyectos
    public function filtroResenia($idResenia)
    {
        $stage = DB::table('stages')
            ->where('active', '=', 1)
            ->get();
        $etapa_activa = $stage->pluck('id')->first();


        // 1 => Evaluado, 2 = > En Proceso, 3 = > NO Evaluado, 4 = > En Evaluacion
        if ($idResenia == 1) {
            $proyectosConAlgunResenia = DB::table('projects')->join('reviews', 'reviews.project_id', 'projects.id')
                ->where('projects.title', '!=', 'null')
                ->where('projects.active', '=', 1)
                ->where('reviews.type', '=', 'review')
                ->select('reviews.*')
                ->orderBy('reviews.project_id')
                ->get();
            // dd($proyectosConAlgunResenia);

            // Quitar reviews de usuarios no asignados a ese proyecto
            foreach ($proyectosConAlgunResenia as $key => $value) {
                $reviewAsignada = DB::table('project_revisor')
                    ->where('revisor_id', '=', $value->revisor_id)
                    ->where('project_id', '=', $value->project_id)
                    ->where('stage_id', '=', $etapa_activa)
                    ->get();

                // dd($reviewAsignada);
                if ($reviewAsignada->isEmpty()) {
                    $proyectosConAlgunResenia->pull($key);
                }
            }

            // dd($proyectosConAlgunResenia);


            $commentRevisorUnico = array();

            foreach ($proyectosConAlgunResenia as $key => $value) {
                if (empty($commentRevisorUnico[$value->project_id])) {

                    $commentRevisorUnico[$value->project_id] = array();
                }

                array_push($commentRevisorUnico[$value->project_id], $value->revisor_id);
            }

            $reviewsFiltradas = array();
            foreach ($commentRevisorUnico as $keyUnico => $value) {
                $reviewsFiltradas[$keyUnico] = count(array_unique($value));
            }

            // dd($reviewsFiltradas);

            $cantidadRevisoresPorProyecto = DB::table('projects')
                ->join('project_revisor', 'project_revisor.project_id', '=', 'projects.id')
                // ****
                ->join('stages', 'stages.id', '=', 'project_revisor.stage_id')
                ->where('stages.active', '=', 1)
                ->where('projects.title', '!=', 'null')
                ->where('projects.active', '=', 1)
                // ->where('project_revisor.stage_id', '=', $etapa_activa)

                // ->where('project_revisor.group_id', '<>', NULL)

                ->select('projects.id as idProyecto', DB::raw('count(projects.id) as cantidadRevisores'))
                ->groupBy('projects.id')
                ->get();

            // dd($cantidadRevisoresPorProyecto);

            $collectionFiltrado = collect();
            $arrayCadaFiltrado = array();
            $arrayIdProyectosOk = array();
            foreach ($cantidadRevisoresPorProyecto as $key => $proyecto) {
                foreach ($reviewsFiltradas as $keyIdProyecto => $reviewCantidad) {
                    if ($keyIdProyecto == $proyecto->idProyecto) {
                        if ($proyecto->cantidadRevisores <= $reviewCantidad) {
                            $arrayCadaFiltrado['idProyecto'] = $proyecto->idProyecto;
                            $arrayCadaFiltrado['cantidadRevisores'] = $proyecto->cantidadRevisores;
                            $arrayCadaFiltrado['cantidadCommentRecibida'] = $reviewCantidad;

                            $collectionFiltrado->push($arrayCadaFiltrado);
                            array_push($arrayIdProyectosOk, $keyIdProyecto);
                        }
                    }
                }
            }

            \Session::flash('detalleEvaluado', $collectionFiltrado);

            // dd($arrayFiltrado);
            // dd($collectionFiltrado);
            return $arrayIdProyectosOk;

        } elseif ($idResenia == 2) {
            $proyectosConAlgunResenia = DB::table('projects')->join('reviews', 'reviews.project_id', 'projects.id')
                ->where('projects.title', '!=', 'null')
                ->where('projects.active', '=', 1)
                ->where('reviews.type', '=', 'review')
                ->select('reviews.*')
                ->orderBy('reviews.project_id')
                ->get();

            // Quitar reviews de usuarios no asignados a ese proyecto
            foreach ($proyectosConAlgunResenia as $key => $value) {
                $reviewAsignada = DB::table('project_revisor')
                    ->where('revisor_id', '=', $value->revisor_id)
                    ->where('project_id', '=', $value->project_id)
                    ->where('stage_id', '=', $etapa_activa)
                    ->get();

                // dd($reviewAsignada);
                if ($reviewAsignada->isEmpty()) {
                    $proyectosConAlgunResenia->pull($key);
                }
            }

            $commentRevisorUnico = array();

            foreach ($proyectosConAlgunResenia as $key => $value) {
                if (empty($commentRevisorUnico[$value->project_id])) {

                    $commentRevisorUnico[$value->project_id] = array();
                }

                array_push($commentRevisorUnico[$value->project_id], $value->revisor_id);
            }

            $reviewsFiltradas = array();
            foreach ($commentRevisorUnico as $keyUnico => $value) {
                $reviewsFiltradas[$keyUnico] = count(array_unique($value));
            }

            // dd($reviewsFiltradas);

            $cantidadRevisoresPorProyecto = DB::table('projects')
                ->join('project_revisor', 'project_revisor.project_id', '=', 'projects.id')
                // ****
                ->join('stages', 'stages.id', '=', 'project_revisor.stage_id')
                ->where('stages.active', '=', 1)
                // ***

                ->where('projects.title', '!=', 'null')
                ->where('projects.active', '=', 1)
                // ->where('project_revisor.stage_id', '=', $etapa_activa)
                ->where('project_revisor.group_id', '<>', NULL)
                ->select('projects.id as idProyecto', DB::raw('count(projects.id) as cantidadRevisores'))
                ->groupBy('projects.id')
                ->get();

            // dd($cantidadRevisoresPorProyecto);

            $collectionFiltrado = collect();
            $arrayCadaFiltrado = array();
            $arrayIdProyectosOk = array();
            foreach ($cantidadRevisoresPorProyecto as $key => $proyecto) {
                foreach ($reviewsFiltradas as $keyIdProyecto => $reviewCantidad) {
                    if ($keyIdProyecto == $proyecto->idProyecto) {
                        if ($proyecto->cantidadRevisores > $reviewCantidad) {
                            $arrayCadaFiltrado['idProyecto'] = $proyecto->idProyecto;
                            $arrayCadaFiltrado['cantidadRevisores'] = $proyecto->cantidadRevisores;
                            $arrayCadaFiltrado['cantidadCommentRecibida'] = $reviewCantidad;

                            $collectionFiltrado->push($arrayCadaFiltrado);
                            array_push($arrayIdProyectosOk, $keyIdProyecto);
                        }
                    }
                }
            }

            \Session::put('detalleEnProceso', $collectionFiltrado);

            // dd($arrayFiltrado);
            // dd($collectionFiltrado);

            // dd($projects);

            return $arrayIdProyectosOk;

        } elseif ($idResenia == 3) {
            $quitarEvaluados = DB::table('projects')->join('reviews', 'reviews.project_id', 'projects.id')
                ->join('project_revisor', 'project_revisor.revisor_id', '=', 'reviews.revisor_id')
                ->join('stages', 'stages.id', '=', 'project_revisor.stage_id')
                ->where('stages.active', '=', 1)
                ->where('projects.title', '!=', 'null')
                ->where('projects.active', '=', 1)
                ->where('reviews.type', '=', 'review')
                ->select('projects.id as idProyecto')
                ->distinct()
                ->get();

            $proyectosExcluidos = $quitarEvaluados->pluck('idProyecto')->toArray();
            // dd($proyectosExcluidos);
            return $proyectosExcluidos;
            
        } elseif ($idResenia == 4) {
            $enReevaluacion = DB::table('projects')
                ->join('project_revisor', 'project_revisor.project_id', '=', 'projects.id')
                ->join('stages', 'stages.id', '=', 'project_revisor.stage_id')
                ->where('stages.active', '=', 1)
                ->where('projects.title', '!=', 'null')
                ->where('projects.active', '=', 1)
                ->where('project_revisor.group_id', '<>', 'NULL')
                ->select('projects.id as idProyecto', 'project_revisor.group_id')
                // ->distinct()
                ->groupBy('projects.id')
                ->get();

            // dd($enReevaluacion);
            $proyectosEnReevaluacion = $enReevaluacion->pluck('idProyecto')->toArray();
            // dd($proyectosEnReevaluacion);
            return $proyectosEnReevaluacion;
        }
    }


    // Listado de proyectos archivados
    public function archivedList()
    {
        $projects = Project::where('projects.title', '!=', 'null')
            ->where('projects.active', '=', 0)
            ->select('projects.id', 'projects.title', 'projects.origin_id')
            ->orderBy('origin_id', 'asc')
            ->oldest()
            ->get();
        // dd($projects);

        $total_proyectos = Project::where('title', '!=', 'null')
            ->where('active', '=', 0)
            ->count();

        $args = [
            'proyectos' => $projects,
            'total_proyectos' => $total_proyectos,
        ];

        return view('admin.models.inscription.collectionArchived', $args);
    }

    // Restaura proyectos
    public function restoreProject($id)
    {
        $proyecto = Project::where('id', '=', $id)
            ->get()
            ->first();

        $proyecto->active = 1;
        $proyecto->save();

        return back();
    }

    // Lista de postulantes por paises
    public function postulantesPorPais($tipo)
    {
        $projects = Project::join('users', 'users.id', '=', 'projects.user_id')
            ->join('userdata', 'userdata.user_id', '=', 'users.id')
            ->join('countries', 'countries.id', '=', 'userdata.country_id')
            ->where('projects.title', '!=', 'null')
            ->where('projects.active', '=', 1)
            ->where('projects.type', '=', $tipo)
            ->select('userdata.name', 'userdata.surname', 'userdata.dni_type', 'userdata.dni', 'userdata.city', 'users.email', 'countries.es', 'projects.type')
            ->groupBy('users.email')
            ->orderBy('countries.es', 'asc')
            ->orderBy('users.email', 'asc')
            ->get();
        // dd($projects);

        foreach ($projects as $key => $value) {
            $tipo = "";
            if ($value->type == "artist") {
                $tipo = "artista";
            } elseif ($value->type == "curator") {
                $tipo = "curador";
            }

            echo($value->es . "," . $value->email . "," . $value->name . "," . $value->surname . "," . $tipo . "," . $value->city . "<br>");
        }
    }

}