<?php

namespace App\Http\Controllers;

use App\Attachment;
use App\Project;
use App\Type;
use Illuminate\Http\Request;
use Illuminate\Http\UploadedFile;
use Pion\Laravel\ChunkUpload\Exceptions\UploadMissingFileException;
use Pion\Laravel\ChunkUpload\Handler\AbstractHandler;
use Pion\Laravel\ChunkUpload\Handler\HandlerFactory;
use Pion\Laravel\ChunkUpload\Receiver\FileReceiver;
use Illuminate\Http\Response;
use Storage;

class UploadController extends Controller
{
    /**
     * Handles the file upload
     *
     * @param Request $request
     *
     * @return \Illuminate\Http\JsonResponse
     *
     * @throws UploadMissingFileException
     */
    public function upload(Request $request)
    {
        // Validacion de mime
        $arrayDeMimes = ['application/octet-stream', 'application/pdf', 'audio/mpeg', 'image/jp2', 'image/jpeg', 'image/png', 'image/tiff', 'image/webp', 'video/mp4', 'video/quicktime', 'video/x-m4v'];
        $mime= \File::mimeType($request->file);

        // Impide la subida del archivo si no tiene un mime permitido
        if (! in_array($mime, $arrayDeMimes)) {
            $urlActual = $_SERVER['HTTP_REFERER'];
            $partirUrl = explode('/inscription', $urlActual);
            $arrayUrl = explode('/', $partirUrl[0]);
            $lang = end($arrayUrl);

            $mensajeError = "File not allowed";
            switch ($lang) {
                case 'en':
                    $mensajeError = "File not allowed";
                    break;

                case 'es':
                    $mensajeError = "Archivo no permitido";
                    break;

                case 'fr':
                    $mensajeError = "Fichier non autorisé";
                    break;

                case 'pt':
                    $mensajeError = "Arquivo não permitido";
                    break;
                
                default:
                    $mensajeError = "File not allowed";
                    break;
            }

            return response($mensajeError, 301)->header('Content-Type', 'text/plain');
            exit();
        }
        
        // create the file receiver
        $receiver = new FileReceiver("file", $request, HandlerFactory::classFromRequest($request));

        // check if the upload is success
        if ($receiver->isUploaded()) {

            // receive the file
            $save = $receiver->receive();

            // check if the upload has finished (in chunk mode it will send smaller files)
            if ($save->isFinished()) {
                // save the file and return any response you need
                return $this->saveFile($save->getFile());
            } else {
                // we are in chunk mode, lets send the current progress

                /** @var AbstractHandler $handler */
                $handler = $save->handler();

                return response()->json([
                    "done" => $handler->getPercentageDone(),
                ]);
            }
        } else {
            throw new UploadMissingFileException();
        }
    }

    /**
     * Saves the file
     *
     * @param UploadedFile $file
     *
     * @return \Illuminate\Http\JsonResponse
     */
    protected function saveFile(UploadedFile $file)
    {
        $fileData = \File::get($file->path());

        $fileName = $this->createFilename($file);
        // Group files by mime type
        $mime = str_replace('/', '-', $file->getMimeType());
        // Group files by the date (week
        $dateFolder = date("Y-m-W");

        // Build the file path
        $filePath = "upload/{$mime}/{$dateFolder}/";
        $finalPath = public_path("/" . $filePath);
        // $finalPath = storage_path("app/" . $filePath);

        // move the file name (Sube al hosting)
        $file->move($finalPath, $fileName);

        // Subir a Google Drive
        // $this->saveAttachmentsInGoogleDrive($mime, $dateFolder, $fileName, $fileData);

        if ($finalPath) {
//            var_dump($_POST['uid']);

            $project = Project::where('hash',$_POST['uid'])->first();

            $type = Type::where('slug',$_POST['type'])->first();

            $attach = new Attachment();
            // $attach->path = $finalPath;
            $attach->path = $filePath;
            $attach->filename = $fileName;
            $attach->project_id = $project->id;
            $attach->mime = $mime;
            $attach->hash = $_POST['uid'];
            $attach->type_id = $type->id;
            $attach->save();

        }


        return response()->json([
            'path' => $filePath,
            'name' => $fileName,
            'mime_type' => $mime,
            'attachment_id'=>$attach->id,
        ]);
    }

    /**
     * Create unique filename for uploaded file
     * @param UploadedFile $file
     * @return string
     */
    protected function createFilename(UploadedFile $file)
    {
        $extension = $file->getClientOriginalExtension();
        $filename = str_replace("." . $extension, "", str_replace("#","",$file->getClientOriginalName())); // Filename without extension

        // Add timestamp hash to name of the file
        $filename .= "_" . md5(time()) . "." . $extension;

        return $filename;
    }

    public function delete($id,$name){
        $attachment = Attachment::where('id',$id)->where('filename',$name)->first();
//
        $attachment->delete();
    }


    // Guarda los archivos adjuntos en Google Drive
    public function saveAttachmentsInGoogleDrive($paramMime, $paramFecha, $nombreDeArchivo, $archivoAdjunto){
        $dir = '/';
        $recursive = false; // Get subdirectories also?
        $creaMime = false;
        $creaFecha = false;
        $nuevo_mime = $paramMime;
        $nueva_fecha = $paramFecha;

        $contents = collect(Storage::cloud()->listContents($dir, $recursive));
        $dir = $contents->where('type', '=', 'dir')
            ->where('filename', '=', 'upload')
            ->first(); // There could be duplicate directory names!

        // Si existe la carpeta 'upload':
        if ($dir) {
            $contents = collect(Storage::cloud()->listContents($dir['path'], $recursive));
            $mime_busqueda = $contents->where('type', '=', 'dir')
                ->where('filename', '=', $nuevo_mime)
                ->first();
            
            // Si NO existe la carpeta 'mime':
            if (is_null($mime_busqueda)) {
                $creaMime = Storage::cloud()->makeDirectory($dir['path'].'/'.$nuevo_mime);
            }else{
                $contents = collect(Storage::cloud()->listContents($mime_busqueda['path'], $recursive));
                $fecha_busqueda = $contents->where('type', '=', 'dir')
                    ->where('filename', '=', $nueva_fecha)
                    ->first();

                // Si NO existe la carpeta 'fecha':
                if (is_null($fecha_busqueda)) {
                    $creaFecha = Storage::cloud()->makeDirectory($mime_busqueda['path'].'/'.$nueva_fecha);
                }else{
                    // dd('sube aca 1');
                    Storage::cloud()->put($fecha_busqueda['path'].'/'.$nombreDeArchivo, $archivoAdjunto);
                }
            }

            // Si recien se creó la carpeta 'mime':
            if ($creaMime) {
                $contents = collect(Storage::cloud()->listContents($dir['path'], $recursive));
                $mime_busqueda = $contents->where('type', '=', 'dir')
                    ->where('filename', '=', $nuevo_mime)
                    ->first();

                $contents = collect(Storage::cloud()->listContents($mime_busqueda['path'], $recursive));
                $fecha_busqueda = $contents->where('type', '=', 'dir')
                    ->where('filename', '=', $nueva_fecha)
                    ->first();

                // Si NO existe la carpeta 'fecha':
                if (is_null($fecha_busqueda)) {
                    $creaFecha = Storage::cloud()->makeDirectory($mime_busqueda['path'].'/'.$nueva_fecha);
                }else{
                    // dd('sube aca 2');
                    Storage::cloud()->put($fecha_busqueda['path'].'/'.$nombreDeArchivo, $archivoAdjunto);
                }
            }

            // Si recien se creó la carpeta 'fecha':
            if ($creaFecha) {
                $contents = collect(Storage::cloud()->listContents($dir['path'], $recursive));
                $mime_busqueda = $contents->where('type', '=', 'dir')
                    ->where('filename', '=', $nuevo_mime)
                    ->first();

                $contents = collect(Storage::cloud()->listContents($mime_busqueda['path'], $recursive));
                $fecha_busqueda = $contents->where('type', '=', 'dir')
                    ->where('filename', '=', $nueva_fecha)
                    ->first();

                // Si NO existe la carpeta 'fecha' ACA, está mal:
                if (is_null($fecha_busqueda)) {
                    $creaFecha = Storage::cloud()->makeDirectory($mime_busqueda['path'].'/'.$nueva_fecha);
                    // dd('crea fecha 3');
                }else{
                    // dd('sube aca 3');
                    Storage::cloud()->put($fecha_busqueda['path'].'/'.$nombreDeArchivo, $archivoAdjunto);
                }
            }

        }
    }
}