<?php

namespace App;

use Illuminate\Notifications\Notifiable;
use Illuminate\Foundation\Auth\User as Authenticatable;
use Spatie\Permission\Traits\HasRoles;
use App\Notifications\MailResetPasswordToken;

class User extends Authenticatable
{
    use Notifiable;
    use HasRoles;

    /**
     * The attributes that are mass assignable.
     *
     * @var array
     */
    protected $fillable = [
        'name', 'email', 'password',
    ];

    /**
     * The attributes that should be hidden for arrays.
     *
     * @var array
     */
    protected $hidden = [
        'password', 'remember_token',
    ];

    public $timestamps = true;

    /**
     * Send a password reset email to the user
     */
    public function sendPasswordResetNotification($token)
    {
        $this->notify(new MailResetPasswordToken($token));
    }

    // RELACIONES:
    
    public function projects(){
        return $this->hasMany('App\Project', 'user_id', 'id');
    }

    public function assignment(){
        return $this->hasMany('App\Assignment', 'revisor_id', 'id');
    }
 
    public function inscriptions(){
        return $this->hasMany('App\Inscription', 'user_id', 'id');
    }

    // Equipos donde el Usuario es Dueño
    public function ownerTeams(){
        return $this->hasMany('App\Team', 'user_id', 'id');
    }

    // Review de revisor al proyecto
    public function reviews(){
        return $this->hasMany('App\Review', 'revisor_id', 'id')->where('type', '=', 'review');
    }

    // Mensaje de revisor o postulante en proyecto
    public function messages(){
        return $this->hasMany('App\Review', 'revisor_id', 'id')->where('type', '=', 'message');
    }

    public function userdata(){
        return $this->hasOne('App\Userdata', 'user_id', 'id');
    }

    // Equipos donde el Usuario es Miembro
    public function memberTeams(){
        return $this->belongsToMany('App\Team', 'team_user', 'user_id', 'team_id');
    }
}
