<?php

/*
|--------------------------------------------------------------------------
| Web Routes
|--------------------------------------------------------------------------
|
| Here is where you can register web routes for your application. These
| routes are loaded by the RouteServiceProvider within a group which
| contains the "web" middleware group. Now create something great!
|
*/

use App\Http\Controllers\InscriptionController;
use Spatie\Permission\Exceptions\UnauthorizedException;

use App\User;
use App\Stage;
use App\Project;


// Incluye reseteo de password
Auth::routes();

// Convocatoria
Route::group(['prefix' => LaravelLocalization::setLocale()], function () {
    /** ADD ALL LOCALIZED ROUTES INSIDE THIS GROUP **/
    Route::get('/', 'InscriptionController@create');
    Route::get('/home', 'InscriptionController@create');
    Route::get('/inscription/documents', 'InscriptionController@documents');
    Route::get('/inscription/help', 'InscriptionController@help');

//    Route::get('/inscription', 'InscriptionController@index');
    Route::get('/inscription/create/{type}', 'InscriptionController@create');
    Route::get('email', 'TestController@index');

    Route::get('/', function(){
//       redirect('/inscription/create/artist');
        InscriptionController::create('artist');
    });

});


// Proyectos del postulante
Route::resource('my-projects', 'Admin\MyProjectController')->middleware('role:superadmin|administrador|revisor|postulante');
Route::post('my-projects/storeMessage', ['as' => 'my-projects.storeMessage', 'uses' => 'Admin\MyProjectController@storeMessage']);

// Postulantes por pais
Route::get('postulantesPorPais/{tipo}', 'Admin\InscriptionController@postulantesPorPais');

// Todos los usuarios
Route::get('postulantesYmiembros', function() {
    $proyectos = \App\Project::with('user.userdata', 'teams.members.userdata')
                            ->where('title', '<>', null)
                            ->where('active', '=', 1)
                            ->get();

    $usuarios = array();

    foreach ($proyectos as $key => $cada_proyecto) {
        array_push($usuarios, $cada_proyecto->user->email . ',' . $cada_proyecto->user->userdata->name . ',' . $cada_proyecto->user->userdata->surname);
        // echo($cada_proyecto->user->email . '<br>');
        
        if ($cada_proyecto->teams->name != 'sin equipo') {
            // echo('<hr>');
            foreach ($cada_proyecto->teams->members as $key => $cada_miembro) {
                array_push($usuarios, $cada_miembro->email . ',' . $cada_miembro->userdata->name . ',' . $cada_miembro->userdata->surname);
                // echo('TEAM - ' . $cada_miembro->email . '<br>');
            }
            // echo('<hr>');
        }
    }


    // Listado limpio
    $usuarios_unicos = array_unique($usuarios);
    foreach ($usuarios_unicos as $key => $value) {
       echo($value . '<br>');
    }
});

// Todos los usuarios con datos completos
Route::get('exportUsuarios', function() {
    $proyectos = \App\Project::with('user.userdata', 'teams.members.userdata')
                            ->where('title', '<>', null)
                            ->where('active', '=', 1)
                            ->get();

    $usuarios = array();

    array_push($usuarios, 'email' 
                                . '&Tab;' . 'nombre' 
                                . '&Tab;' . 'apellido'
                                . '&Tab;' . 'tipo de dni'
                                . '&Tab;' . 'dni'
                                . '&Tab;' . 'dirección'
                                . '&Tab;' . 'ciudad'
                                . '&Tab;' . 'país'
                                . '&Tab;' . 'nacionalidad'
                                . '&Tab;' . 'fecha de nacimiento'
                                . '&Tab;' . 'telefono'
                                . '&Tab;' . 'celular'
        );

    foreach ($proyectos as $key => $cada_proyecto) {
        array_push($usuarios, $cada_proyecto->user->email 
                                . '&Tab;' . $cada_proyecto->user->userdata->name 
                                . '&Tab;' . $cada_proyecto->user->userdata->surname
                                . '&Tab;' . $cada_proyecto->user->userdata->dni_type
                                . '&Tab;' . $cada_proyecto->user->userdata->dni
                                . '&Tab;' . $cada_proyecto->user->userdata->address
                                . '&Tab;' . $cada_proyecto->user->userdata->city
                                . '&Tab;' . $cada_proyecto->user->userdata->country->es
                                . '&Tab;' . $cada_proyecto->user->userdata->nacionality
                                . '&Tab;' . $cada_proyecto->user->userdata->birthdate
                                . '&Tab;' . $cada_proyecto->user->userdata->telephone
                                . '&Tab;' . $cada_proyecto->user->userdata->cellphone
        );
        // echo($cada_proyecto->user->email . '<br>');
        
        if ($cada_proyecto->teams->name != 'sin equipo') {
            // echo('<hr>');
            foreach ($cada_proyecto->teams->members as $key => $cada_miembro) {
                array_push($usuarios, $cada_miembro->email 
                                    . '&Tab;' . $cada_miembro->userdata->name 
                                    . '&Tab;' . $cada_miembro->userdata->surname
                                    . '&Tab;' . $cada_miembro->userdata->dni_type
                                    . '&Tab;' . $cada_miembro->userdata->dni
                                    . '&Tab;' . $cada_miembro->userdata->address
                                    . '&Tab;' . $cada_miembro->userdata->city
                                    . '&Tab;' . $cada_miembro->userdata->country->es
                                    . '&Tab;' . $cada_miembro->userdata->nacionality
                                    . '&Tab;' . $cada_miembro->userdata->birthdate
                                    . '&Tab;' . $cada_miembro->userdata->telephone
                                    . '&Tab;' . $cada_miembro->userdata->cellphone
                );
                // echo('TEAM - ' . $cada_miembro->email . '<br>');
            }
            // echo('<hr>');
        }
    }


    // Listado limpio
    $usuarios_unicos = array_unique($usuarios);
    foreach ($usuarios_unicos as $key => $value) {
       echo($value . '<br>');
    }
});

//ADMINISTRACION
Route::group(['prefix' => 'admin'], function() {
    // ver formulario de login
    Route::get('login', function () {
        return view('admin.login');
    });

    // procesar el login
    Route::post('login', [ 'as' => 'loginAdmin', 'uses' => 'Admin\LoginAdminController@iniciarAdmin']);

    // Desloguearse
    Route::get('logout', 'Admin\LoginAdminController@cerrar');

    //Panel raiz
    Route::get('/', 'Admin\DashboardController@index');

    // Cambiar contraseña
    Route::get('changePassword', ['as' => 'changePassword', 'uses' => 'Admin\LoginAdminController@formularioCambiarPassword']);
    Route::post('changePassword', ['as' => 'saveChangePassword', 'uses' => 'Admin\LoginAdminController@cambiarPassword']);


    //Panel con permisos
    Route::group(['middleware' => ['role:superadmin|administrador|revisor']], function () {
        // Inscripciones
        Route::resource('inscription', 'Admin\InscriptionController')->middleware('role:superadmin|administrador|revisor');

        // archivar proyectos
        Route::get('archiveProject/{idProject}', 'Admin\InscriptionController@archiveProject')->middleware('role:superadmin');
        Route::get('archivedList', 'Admin\InscriptionController@archivedList')->middleware('role:superadmin');
        Route::get('restoreProject/{idProject}', 'Admin\InscriptionController@restoreProject')->middleware('role:superadmin');





//        Route::get('inscription/{?group}', 'Admin\InscriptionController@index')->middleware('role:revisor');

        //PRESELECCIONAR
        Route::post('preselect/{idProject}', 'Admin\InscriptionController@preselectProject')->middleware('role:superadmin|administrador');
        // DESCARGAR PRESELECCIONADOS
        Route::get('preselect/download/{csv}', function(){

//            $table = \App\Project::
//            join('userdata', 'userdata.user_id', '=', 'projects.id')
//                ->join('cities', 'cities.id', '=', 'userdata.city_id')
//                ->join('countries', 'countries.id', '=', 'userdata.country_id')
//                ->join('users', 'users.id', '=', 'userdata.user_id')
//                ->join('reviews', 'reviews.project_id', '=', 'projects.id')
//                ->where('preselected', '=', 1)
//                ->where('projects.title', '!=', 'null')
//                ->where('projects.active', '=', 1)
//                ->select('cities.city','countries.es','userdata.nacionality','userdata.name','userdata.surname','users.email','projects.title','reviews.rating','reviews.comment')
//                ->orderBy('projects.origin_id', 'asc')
//                ->with('user')
//                ->get();


            //TENGO QUE TRAER EL PAIS EN EL IDIOMA CORRESPONDIENTE
            //COLUMNAS QUE DEBO TRAER:
            //Ciudad País Nacionalidad Nombre Apellido Mail Titulo Observaciones
            //DARLE ESTILO AL BOTON
            $table = \App\Project::
            join('userdata', 'userdata.user_id', '=', 'projects.id')
                ->join('cities', 'cities.id', '=', 'userdata.city_id')
                ->join('countries', 'countries.id', '=', 'userdata.country_id')
                ->join('users', 'users.id', '=', 'userdata.user_id')
                ->where('preselected', '=', 1)
                ->where('projects.title', '!=', 'null')
                ->where('projects.active', '=', 1)
                ->select('cities.city','countries.es','userdata.nacionality','userdata.name','userdata.surname','users.email','projects.title')
                ->orderBy('projects.origin_id', 'asc')
                ->with('user')
                ->get();

            $filename = "descarga_de_proyectos.csv";
            $delimiter = ";"; //uso punto y coma para que al abrirlo con excel automaticamente lo separe en columnas.
            $handle = fopen($filename, 'w+');
            //add BOM to fix UTF-8 in Excel
            fputs($handle, $bom =( chr(0xEF) . chr(0xBB) . chr(0xBF) ));
            fputcsv($handle, array('Ciudad', 'País', 'Nacionalidad', 'Nombre', 'Apellido', 'Mail', 'Título', 'Observaciones'), $delimiter);

            foreach($table as $row) {
                fputcsv($handle, array($row['city'], $row['country'], $row['nacionality'], $row['name'], $row['surname'], $row['email'], $row['title'], $row['rating']),$delimiter);
            }

            fclose($handle);

            $headers = array('Content-Type' => 'text/csv',);

            return Response::download($filename, 'descarga_de_proyectos.csv', $headers);
        });

        // Usuarios
        Route::resource('user', 'Admin\UserController')->middleware('role:superadmin|administrador');

        //Select de etapas y proyectos (user)
        Route::get('getStages', 'Admin\UserController@getStages');
        Route::get('getProjects', 'Admin\UserController@getProjects');
        Route::post('saveProjects', 'Admin\UserController@saveProjects')->name('saveProjects');
        Route::delete('removeProject/{id}', 'Admin\UserController@removeProject')->name('removeProject');
        Route::get('asignaciones/removeProjectMultiple', 'Admin\UserController@removeProjectMultiple');
        

        // Grupos de revisores
        Route::resource('group', 'Admin\GroupController')->middleware('role:superadmin|administrador');

        //Select de revisores (group)
        Route::get('getRevisorGroup', 'Admin\GroupController@getRevisorGroup');
        Route::post('addRevisorGroup', 'Admin\GroupController@addRevisorGroup')->name('addRevisorGroup');
        Route::delete('removeRevisorGroup/{id}', 'Admin\GroupController@removeRevisorGroup')->name('removeRevisorGroup');

        //Select de etapas y proyectos (group)
        Route::get('getStagesGroup', 'Admin\GroupController@getStagesGroup');
        Route::get('getProjectsGroup', 'Admin\GroupController@getProjectsGroup');
        Route::post('saveProjectsGroup', 'Admin\GroupController@saveProjectsGroup')->name('saveProjectsGroup');
        Route::delete('removeProjectGroup', 'Admin\GroupController@removeProjectGroup')->name('removeProjectGroup');

        // Reseñas
        Route::resource('review', 'Admin\ReviewController');

        // Asignacion de proyectos a revisores
        Route::resource('asignators', 'Admin\AsignatorsController')->middleware('role:superadmin|administrador');
        Route::post('asignators/assignRevisor', 'Admin\AsignatorsController@assignRevisor')->middleware('role:superadmin|administrador');

    });


});


// redirect a formulario de inscripcion
Route::get('/', function(){
    header('location: https://convocatoria.bienalsur.org/inscription/create/artist');
});

// test de envio de email
Route::get('testEmail', 'MailController@TestSendMailInscription');

// SCRIPTS:

// agregar rol a postulantes
// Route::get('agregarRolPostulante', function() {
//     $usuarios = \DB::select('SELECT users.id, users.name, users.email
//                 FROM `users`
//                 LEFT JOIN model_has_roles ON users.id = model_has_roles.model_id
//                 WHERE model_has_roles.model_type IS NULL');
//     // dd($usuarios);

//     foreach ($usuarios as $key => $value) {
//         // echo("ID: ".$value->id." <br>");
//         \DB::insert('INSERT INTO model_has_roles (role_id, model_type, model_id) values (?, ?, ?)', [4, 'App\User', $value->id]);
//     }

//     echo "Listo";
// });



// agregar type "review" a las reseñas
// Route::get('agregarTypeReview', function() {
//     $resenia = \DB::select('SELECT reviews.id FROM `reviews` WHERE `type` IS NULL');
//     // dd($resenia);

//     foreach ($resenia as $key => $value) {
//         // echo("ID: ".$value->id." <br>");
//         \DB::update("update reviews set type = 'review' where id = ?", [$value->id]);
//     }

//     echo "Listo";
// });



// Insertar datos en tabla la Cities
// Route::get('insertarCiudades', function() {
//     $archivoTxt = File::get(storage_path('lista_ciudades.txt'));
    
//     $filaCiudades = explode('@', $archivoTxt);
//     $quitadoEspacioInicial = str_replace("| ", "|", $filaCiudades);
//     $matrizCiudades = str_replace("\r\n", "", $quitadoEspacioInicial);
    
//     array_pop($matrizCiudades);
    
//     $arrayLimpio = array();
//     foreach ($matrizCiudades as $key => $value) {
//         $arrayLimpio[$key] = trim($value);
//     }

//     // Inserta las ciudades en la tabla Cities
//     foreach ($arrayLimpio as $key => $value) {
//         $cadaCiudad = explode("|", $value);
    
//         \DB::insert('INSERT INTO cities (city, country) values (?, ?)', [$cadaCiudad[1], $cadaCiudad[0]]);
//     }

//     echo "Listo insert de ciudades";
// });



// Actualizar la ciudad de cada usuario
// Route::get('actualizarCiudades/{desde}/{hasta}', function($desde, $hasta) {
//     $archivoTxt = File::get(storage_path('lista_ciudades.txt'));
    
//     $filaCiudades = explode('@', $archivoTxt);
//     $quitadoEspacioInicial = str_replace("| ", "|", $filaCiudades);
//     $matrizCiudades = str_replace("\r\n", "", $quitadoEspacioInicial);
    
//     array_pop($matrizCiudades);
    
//     $arrayLimpio = array();
//     $actualizar = array_slice($matrizCiudades, $desde, $hasta);
//     foreach ($actualizar as $key => $value) {
//         $arrayLimpio[$key] = trim($value);
//     }

//     // Actualiza las ciudades
//     foreach ($arrayLimpio as $key => $value) {
//         $arrayCiudades = explode("|", $value);
        
//         foreach ($arrayCiudades as $key => $value) {
//             if ($key == 0) {
//                 continue;
//             }

//             $get_id_pais = \DB::table('countries')
//                             ->where('es', '=', $arrayCiudades[0])
//                             ->select('id')
//                             ->get()
//                             ->first();
                            
//             $id_pais = $get_id_pais->id;
            
//             $get_id_city = \DB::table('cities')
//                             ->where('city', '=', $arrayCiudades[1])
//                             ->where('country', '=', $arrayCiudades[0])
//                             ->select('id')
//                             ->get()
//                             ->first();
            
//             $id_city = (int)$get_id_city->id;

//             \DB::update('update userdata set city = ?, city_id = ? where city = ? and country_id = ?', [$arrayCiudades[1], $id_city, $value, $id_pais]);
//         }
//     }

//     echo "Listo desde: ".$desde."<br>";
// });

// Insertar proyectos grupales
// Route::get('insertarProyectosGrupales', function() {
//     $rating = 6;
//     $id_liliana = 856;
//     $id_farina = 858;

//     $id_grupo_liliana = 3;
//     $id_grupo_farina = 4;

//     $excluidos_liliana= array();
//     $excluidos_farina= array();

//     $asignados_liliana= array();
//     $asignados_farina= array();

//     $contador_liliana = 0;
//     $contador_farina = 0;


//     $puntuados_farina = \DB::select('select project_id as id from reviews where revisor_id = ? and rating = ?', [858, 6]);
//     // dd($puntuados_farina);

//     // AGREGAR A LILIANA
//     foreach ($puntuados_farina as $keyPF => $valuePF) {
//         array_push($asignados_liliana, $valuePF->id);

//              \DB::insert('INSERT INTO project_revisor (project_id, revisor_id, stage_id, group_id) values (?, ?, ?, ?)', [$valuePF->id, $id_liliana, 1, $id_grupo_liliana]);
//     }

//     $todos_los_proyectos = \DB::table('projects')
//             ->join('reviews', 'reviews.project_id', '=', 'projects.id')

//             ->select('projects.id as id', 'reviews.revisor_id')

//             ->where('projects.title', '!=', null)
//             ->where('projects.active', '=', 1)
//             ->where(function($q) use ($rating) {
//              $q->where('reviews.type', '=', 'review');
//              $q->where('reviews.rating', '=', $rating);
//             })
           
            
//             ->orderBy('projects.id')

//             ->get();

//     // FARINA
//     foreach ($todos_los_proyectos as $key => $value) {
//         if ($value->revisor_id == $id_farina) {
//             array_push($excluidos_farina, $value->id);
//         }else{
//             // Si no esta asignado
//             if (! in_array($value->id, $asignados_liliana)) {
//                 array_push($asignados_farina, $value->id);

//                  \DB::insert('INSERT INTO project_revisor (project_id, revisor_id, stage_id, group_id) values (?, ?, ?, ?)', [$value->id, $id_farina, 1, $id_grupo_farina]);

//                 ++$contador_farina;
//             }
//         }
//     }

//     // dd($excluidos_liliana);
//     // dd($asignados_liliana);

//     // dd($excluidos_farina);
//     // dd($asignados_farina);

//     echo "Listo";
// });





// REASIGNAR (2DA) a liliana

// Route::get('cantidadRevisores', function() {
//     $sin_grupo = DB::table('project_revisor')
//         ->select('project_id')
//         ->where('group_id', '=', null)
//         ->get()
//         ->pluck('project_id')
//         ->toArray();

//     // dd($sin_grupo);

//     $CON_GRUPO = DB::table('project_revisor')
//         ->select('project_id')
//         ->where('group_id', '!=', null)
//         ->get()
//         ->pluck('project_id')
//         ->toArray();

//     // dd($CON_GRUPO);


//     $proyectos_viejos_evaluados_con_6 = DB::table('reviews')
//         ->select('*',  DB::raw('COUNT(*) as count'))
//         ->where('rating', '=', 6)
//         // ->where('revisor_id', '=', 856)
//         ->whereNotIn('project_id', $CON_GRUPO)
//         ->groupBy('project_id')
//         // ->groupBy('revisor_id')
//         // ->having('count', '>=', 1)
//         // ->orderBy('project_id')
//         ->get()
//         ->pluck('project_id')
//         ->toArray();

//     // dd($proyectos_viejos_evaluados_con_6);

//     $id_liliana = 856;
//     $id_grupo_liliana = 3;
//     foreach ($proyectos_viejos_evaluados_con_6 as $key => $value) {
//         // dd($value);
//         // \DB::insert('INSERT INTO project_revisor (project_id, revisor_id, stage_id, group_id) values (?, ?, ?, ?)', [$value, $id_liliana, 1, $id_grupo_liliana]);
//     }

//     dd("asignados a liliana");
// });

// Marcar usuarios para convocatoria_video
Route::get('export_convocatoria_video', function() {
    $projects = \App\Project::
                        join('taggable_taggables', 'taggable_taggables.taggable_id', '=', 'projects.id')
                        ->join('taggable_tags', 'taggable_tags.tag_id', '=', 'taggable_taggables.tag_id')
                        ->where('projects.title', '!=', 'null')
                        ->where('projects.active', '=', 1)
                        //1 :foto, 5: video, 10: videoinstalacion
                        ->whereIn('taggable_taggables.tag_id', [1, 5, 10])
                        ->select('projects.origin_id', 'projects.title', 'projects.id', 'projects.user_id')
                        ->orderBy('projects.origin_id', 'asc')
                        ->with('user')
                        ->get();
                        // ->unique();
// dd($projects->first()->user->email);

    foreach ($projects as $key => $value) {
        // dd($value->user->id);
        \DB::update("update users set export_video = true where id = ?", [$value->user->id]);
    }

    echo "Listo";
});

// Resetear usuarios para convocatoria_video a NULL
Route::get('reset_export_convocatoria_video', function() {
   \DB::update("update users set export_video = null where export_video = ?", [1]);
    echo "Listo";
});